@@ -3,7 +3,7 @@ package Prty;
 use strict;
 use warnings;
 
-our $VERSION = 1.099;
+our $VERSION = 1.100;
 
 =encoding utf8
 
@@ -14,7 +14,7 @@ Prty - Class library in Perl
 =head1 DESCRIPTION
 
 Diese Klassenbibliothek enthält anwendungsunabhängige Klassen,
-die ich Rahmen von Perl-Projekten entwickelt habe. Die Klassen
+die ich im Rahmen meiner Perl-Projekte entwickelt habe. Die Klassen
 sind nach einheitlichen Prinzipien konzipiert. Die Bibliothek
 befindet sich unter kontinuierlicher Weiterentwicklung.
 
@@ -48,6 +48,18 @@ L<Prty::Config> - Konfigurationsdatei in "Perl Object Notation"
 
 =item *
 
+L<Prty::Confluence::Client> - Confluence-Wiki Client
+
+=item *
+
+L<Prty::Confluence::Markup> - Confluence-Wiki Markup
+
+=item *
+
+L<Prty::Confluence::Page> - Confluence-Wiki Seite
+
+=item *
+
 L<Prty::ContentProcessor> - Prozessor für Abschnitts-Dateien
 
 =item *
@@ -288,18 +300,6 @@ L<Prty::ImagePool::Sequence> - Bild-Sequenz und -Ranges
 
 =item *
 
-L<Prty::ImageSequence::Directory> - Bildsequenz-Verzeichnis
-
-=item *
-
-L<Prty::ImageSequence::File> - Bildsequenz-Datei
-
-=item *
-
-L<Prty::ImageSequence::Filename> - Bildsequenz-Dateiname
-
-=item *
-
 L<Prty::Ipc> - Interprozesskommunikation
 
 =item *
@@ -384,6 +384,10 @@ L<Prty::Progress> - Berechne Fortschrittsinformation
 
 =item *
 
+L<Prty::Rsync> - Aufruf von rsync von Perl aus
+
+=item *
+
 L<Prty::Sdoc> - Sdoc-Generator
 
 =item *
@@ -524,6 +528,26 @@ L<Prty::Time> - Ein Zeitpunkt
 
 =item *
 
+L<Prty::TimeLapse::Directory> - Bildsequenz-Verzeichnis
+
+=item *
+
+L<Prty::TimeLapse::File> - Bildsequenz-Datei
+
+=item *
+
+L<Prty::TimeLapse::Filename> - Bildsequenz-Dateiname
+
+=item *
+
+L<Prty::TimeLapse::RangeDef> - Range-Definitionen
+
+=item *
+
+L<Prty::TimeLapse::Sequence> - Bildsequenz
+
+=item *
+
 L<Prty::Udl> - Universal Database Locator
 
 =item *
@@ -534,7 +558,7 @@ L<Prty::Unindent> - Entferne Einrückung von "Here Document" oder String-Literal
 
 =head1 VERSION
 
-1.099
+1.100
 
 =head1 AUTHOR
 
