@@ -4,7 +4,7 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.099;
+our $VERSION = 1.100;
 
 # -----------------------------------------------------------------------------
 
@@ -181,6 +181,14 @@ sub bindTypes {
                     push @$arr,undef;
                 }
             }
+            elsif ($type eq 'XML') {
+                if ($dbms eq 'oracle') {
+                    push @$arr,{ora_type=>DBD::Oracle::ORA_XMLTYPE()};
+                }
+                else {
+                    push @$arr,undef;
+                }
+            }
             else {
                 push @$arr,$type;
             }
@@ -368,7 +376,7 @@ sub fetch {
 
 =head1 VERSION
 
-1.099
+1.100
 
 =head1 AUTHOR
 
