@@ -4,7 +4,7 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.099;
+our $VERSION = 1.100;
 
 use Prty::File::Video;
 use POSIX ();
@@ -857,9 +857,9 @@ Erzeuge einen Audio-Stream aus Audio-Datei $file.
 
 Beende die Ausgabe, wenn die Dauer $duration erreicht ist.
 
-=item -framerate => $n (Default: 6)
+=item -framerate => $n (Default: 8)
 
-Anzahl Bilder pro/Sekunde.
+Anzahl Bilder pro Sekunde.
 
 =item -loop => $bool (Default: 0)
 
@@ -871,9 +871,21 @@ Zeige das generierte Video im Player an, statt es in einer Datei
 zu speichern. Bei -play=>2 bleibt das Fenster des Players
 offen, bis es per Hand geschlossen wird.
 
+=item -preset => $preset (Default: undef)
+
+Satz an vorgewählten Optionen, für Encoding-Zeit
+vs. Kompressionsrate. Mögliche Werte: ultrafast, superfast,
+veryfast, faster, fast, medium, slow, slower, veryslow. Siehe
+L<https://trac.ffmpeg.org/wiki/Encode/H.264>.
+
 =item -size => "$width:$height" (Default: undef)
 
-Breite und Höhe des generierten Video.
+Breite und Höhe des generierten Video. Ohne Angabe nimmt
+ffmpeg die Größe der Bilder.
+
+=item -videoBitrate => $bitrate (Default: 60_000)
+
+Video-Bitrate in kbit/s.
 
 =item -videoFramerate => $n (Default: 24)
 
@@ -893,11 +905,13 @@ sub imagesToVideo {
 
     my $audio = undef;
     my $duration = undef,
-    my $framerate = 6;
+    my $framerate = 8;
     my $loop = 0;
     my $play = 0;
+    my $preset = undef;
     my $size = undef;
     my $videoFramerate = 24;
+    my $videoBitrate = 60_000;
 
     Prty::Option->extract(\@_,
         -audio=>\$audio,
@@ -905,7 +919,9 @@ sub imagesToVideo {
         -framerate=>\$framerate,
         -loop=>\$loop,
         -play=>\$play,
+        -preset=>\$preset,
         -size=>\$size,
+        -videoBitrate=>\$videoBitrate,
         -videoFramerate=>\$videoFramerate,
     );
     if (@_ == 0 || @_ > 2) {
@@ -963,6 +979,13 @@ sub imagesToVideo {
         $self->addOption('-shortest');
     }
 
+    if (defined $videoBitrate) {
+        $self->addOption('-b:v'=>$videoBitrate.'k');
+    }
+    if (defined $preset) {
+        $self->addOption(-preset=>$preset);
+    }
+
     # * Output
 
     if ($play) {
@@ -1477,7 +1500,7 @@ sub execute {
 
 =head1 VERSION
 
-1.099
+1.100
 
 =head1 AUTHOR
 
