@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.099;
+our $VERSION = 1.100;
 
 use Prty::Option;
 use Scalar::Util ();
@@ -287,6 +287,51 @@ sub readLine {
 
 # -----------------------------------------------------------------------------
 
+=head3 readLines() - Lies mehrere Zeilen von Dateihandle
+
+=head4 Synopsis
+
+    @lines|$lineA = $fh->readLines($n);
+
+=head4 Description
+
+Lies die nächsten $n Zeilen von Dateihandle $fh und liefere diese als
+Liste zurück. Der Zeilentrenner am Ende jeder Zeile wird entfernt.
+Im Skalarkontext liefere eine Referenz auf die Liste, wenn
+Zeilen gelesen wurden, sonst C<undef>.
+
+=head4 Example
+
+Liefere Chunks von 1000 Pfaden:
+
+    my $fh = Prty::FileHandle->new('-|',"find @$dirA -name '*.xml.gz'");
+    while (my $fileA = $fh->readLines(1000)) {
+        ...
+    }
+    $fh->close;
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub readLines {
+    my ($self,$n) = @_;
+
+    my @lines;
+    for (my $i = 0; $i < $n; $i++) {
+        my $line = <$self>;
+        if (!defined $line) {
+            last;
+        }
+        chomp $line;
+        push @lines,$line;
+    }
+
+    return wantarray? @lines: @lines? \@lines: undef;
+}
+
+# -----------------------------------------------------------------------------
+
 =head3 readLineChomp() - Lies Zeile ohne Zeilentrenner von Dateihandle
 
 =head4 Synopsis
@@ -744,7 +789,7 @@ sub captureStderr {
 
 =head1 VERSION
 
-1.099
+1.100
 
 =head1 AUTHOR
 
