@@ -4,7 +4,7 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.099;
+our $VERSION = 1.100;
 
 use Prty::Shell;
 use Prty::File::Image;
@@ -108,7 +108,7 @@ sub addElement {
     if ($$ref) {
         $$ref .= ' ';
     }
-    if ($arg =~ /[\s!]/) {
+    if ($arg =~ /[\s!#]/) {
         $$ref .= "'$arg'";
     }
     else {
@@ -527,7 +527,7 @@ sub morph {
 
 =head1 VERSION
 
-1.099
+1.100
 
 =head1 AUTHOR
 
