@@ -4,9 +4,9 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.099;
+our $VERSION = 1.100;
 
-use Prty::ImageSequence::Directory;
+use Prty::TimeLapse::Directory;
 use Prty::Option;
 use Prty::ImagePool::Sequence;
 
@@ -51,7 +51,7 @@ sub new {
 
     return $class->SUPER::new(
         path=>$path,
-        imageList=>Prty::ImageSequence::Directory->new("$path/img"),
+        imageList=>Prty::TimeLapse::Directory->new("$path/img"),
         sequenceH=>{},
     );
 }
@@ -202,7 +202,7 @@ sub image {
 
 =head1 VERSION
 
-1.099
+1.100
 
 =head1 AUTHOR
 
