@@ -4,7 +4,7 @@ use base qw/Prty::Object/;
 use strict;
 use warnings;
 
-our $VERSION = 1.099;
+our $VERSION = 1.100;
 
 use Prty::Hash;
 
@@ -96,12 +96,15 @@ sub get {
 
 =head4 Synopsis
 
-    @arr|$val = $oh->set(@keyVal);
+    $oh->set(@keyVal);
 
 =head4 Description
 
-Setze die angegebenen Schlüssel/Wert-Paare. Die Methode liefert
-keine Wert zurück.
+Setze die angegebenen Schlüssel/Wert-Paare.
+
+=head4 Returns
+
+nichts
 
 =cut
 
@@ -405,7 +408,7 @@ sub exists {
 
 =head1 VERSION
 
-1.099
+1.100
 
 =head1 AUTHOR
 
