@@ -8,7 +8,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.099;
+our $VERSION = 1.100;
 
 use Prty::Option;
 use Prty::FileHandle;
@@ -662,6 +662,11 @@ wird ausgeschlossen.
 
 Folge Symbolic Links.
 
+=item -leavesOnly => $bool (Default: 0)
+
+Liefere nur Pfade, die kein Anfang eines anderen Pfads sind.
+Anwendungsfall: nur die Blatt-Verzeichnisse eines Verzeichnisbaums.
+
 =item -olderThan => $seconds (Default: 0)
 
 Liefere nur Dateien, die vor mindestens $seconds zuletzt geändert
@@ -724,6 +729,7 @@ sub find {
     my $decode = undef;
     my $exclude = undef;
     my $follow = 1;
+    my $leavesOnly = 0;
     my $olderThan = 0;
     my $outHandle = \*STDOUT;
     my $pattern = undef;
@@ -739,6 +745,7 @@ sub find {
             -decode=>\$decode,
             -exclude=>\$exclude,
             -follow=>\$follow,
+            -leavesOnly=>\$leavesOnly,
             -olderThan=>\$olderThan,
             -outHandle=>\$outHandle,
             -pattern=>\$pattern,
@@ -833,6 +840,23 @@ sub find {
     };
     File::Find::find({wanted=>$sub,follow=>$follow},$dir);
 
+    if ($leavesOnly) {
+        my @arr;
+        for (my $i = 0; $i < @paths; $i++) {
+            my $ok = 1;
+            for (my $j = 0; $j < @paths; $j++) {
+                if ($j != $i && index($paths[$j],$paths[$i]) == 0) {
+                    $ok = 0;
+                    last;
+                }
+            }
+	    if ($ok) {
+		push @arr,$paths[$i];
+	    }
+        }
+        @paths = @arr;
+    }
+
     return wantarray? @paths: \@paths;
 }
 
@@ -876,7 +900,7 @@ sub maxFilename {
 
 =head4 Synopsis
 
-    $max = $class->maxFileNumber($dir);
+    $max = $class->maxFileNumber($dir,@opt);
 
 =head4 Description
 
@@ -886,13 +910,35 @@ NNNNNN beginnen und man die Datei mit der größten Zahl ermitteln
 möchte um einer neu erzeugten Datei die nächsthöhere Nummer
 zuzuweisen.
 
+=head4 Options
+
+=over 4
+
+=item -sloppy => $bool (Default: 0)
+
+Wirf keine Exception, wenn ein Dateiname nicht mit einer Nummer
+beginnt.
+
+=back
+
 =cut
 
 # -----------------------------------------------------------------------------
 
 sub maxFileNumber {
-    my ($class,$dir) = @_;
+    my ($class,$dir) = splice @_,0,2;
+    # @_: @opt
 
+    # Options
+
+    my $sloppy = 0;
+    
+    Prty::Option->extract(\@_,
+        -sloppy=>\$sloppy,
+    );
+
+    # Verarbeitung
+    
     my $max = 0;
     my $dh = Prty::DirHandle->new($dir);
     while (my $file = $dh->next) {
@@ -900,7 +946,10 @@ sub maxFileNumber {
             next;
         }
         my ($n) = $file =~ /^(\d+)/;
-        if (!defined $n) {
+        if (!defined($n)) {
+            if ($sloppy) {
+                next;
+            }
             $class->throw(
                 q{PATH-00099: Dateiname beginnt nicht mit Ziffernfolge},
                 File=>$file,
@@ -1039,6 +1088,51 @@ sub mkdir {
 
 # -----------------------------------------------------------------------------
 
+=head3 rmdir() - Lösche Verzeichnis
+
+=head4 Synopsis
+
+    $class->rmdir($dir);
+
+=head4 Description
+
+Lösche Verzeichnis $dir, falls dieses leer ist. Kann das
+Verzeichnis nicht gelöscht werden, wird eine Exception ausgelöst.
+
+=head4 Arguments
+
+=over 4
+
+=item $dir
+
+Pfad des Verzeichnisses
+
+=back
+
+=head4 Returns
+
+nichts
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub rmdir {
+    my $class = shift;
+    my $dir = shift;
+
+    CORE::rmdir($dir) || do {
+        $class->throw(
+            q{PATH-00005: Verzeichnis kann nicht gelöscht werden},
+            Path=>$dir,
+        );
+    };
+
+    return;
+}
+
+# -----------------------------------------------------------------------------
+
 =head2 Pfad-Operationen
 
 =head3 basename() - Grundname eines Pfads
@@ -1612,7 +1706,7 @@ sub symlinkRelative {
 
 =head1 VERSION
 
-1.099
+1.100
 
 =head1 AUTHOR
 
